"""Data for Home Assistant sensors unit tests."""

from typing import Any
from typing import Dict
from typing import List

discovery_message_expected: List[Dict[str, Any]] = [
    {
        "message": {
            "name": "Voltage",
            "unique_id": "mocked_unipi_voltage_1",
            "state_topic": "mocked_unipi/meter/voltage_1/get",
            "qos": 2,
            "device": {
                "name": "MOCKED Eastron SDM120M - Workspace",
                "identifiers": "mocked_eastron_sdm120m_workspace",
                "model": "SDM120M",
                "sw_version": "202.04",
                "manufacturer": "Eastron",
                "suggested_area": "Workspace",
                "via_device": "MOCKED UNIPI",
            },
            "object_id": "voltage_1",
            "device_class": "voltage",
            "force_update": True,
            "state_class": "measurement",
            "unit_of_measurement": "V",
        },
        "topic": "homeassistant/sensor/mocked_unipi/voltage_1/config",
    },
    {
        "message": {
            "name": "Current",
            "unique_id": "mocked_unipi_current_1",
            "state_topic": "mocked_unipi/meter/current_1/get",
            "qos": 2,
            "device": {
                "name": "MOCKED Eastron SDM120M - Workspace",
                "identifiers": "mocked_eastron_sdm120m_workspace",
                "model": "SDM120M",
                "sw_version": "202.04",
                "manufacturer": "Eastron",
                "suggested_area": "Workspace",
                "via_device": "MOCKED UNIPI",
            },
            "object_id": "current_1",
            "device_class": "current",
            "force_update": True,
            "state_class": "measurement",
            "unit_of_measurement": "A",
        },
        "topic": "homeassistant/sensor/mocked_unipi/current_1/config",
    },
    {
        "message": {
            "name": "Active Power",
            "unique_id": "mocked_unipi_active_power_1",
            "state_topic": "mocked_unipi/meter/active_power_1/get",
            "qos": 2,
            "force_update": True,
            "device": {
                "name": "MOCKED Eastron SDM120M - Workspace",
                "identifiers": "mocked_eastron_sdm120m_workspace",
                "model": "SDM120M",
                "sw_version": "202.04",
                "manufacturer": "Eastron",
                "via_device": "MOCKED UNIPI",
                "suggested_area": "Workspace",
            },
            "object_id": "active_power_1",
            "device_class": "power",
            "state_class": "measurement",
            "unit_of_measurement": "W",
        },
        "topic": "homeassistant/sensor/mocked_unipi/active_power_1/config",
    },
    {
        "message": {
            "name": "MOCKED_FRIENDLY_NAME - APPARENT_POWER",
            "unique_id": "mocked_unipi_mocked_id_apparent_power",
            "state_topic": "mocked_unipi/meter/apparent_power_1/get",
            "qos": 2,
            "force_update": True,
            "device": {
                "name": "MOCKED Eastron SDM120M - Workspace",
                "identifiers": "mocked_eastron_sdm120m_workspace",
                "model": "SDM120M",
                "sw_version": "202.04",
                "manufacturer": "Eastron",
                "via_device": "MOCKED UNIPI",
                "suggested_area": "Workspace",
            },
            "object_id": "mocked_id_apparent_power",
            "icon": "mdi:power-standby",
            "device_class": "apparent_power",
            "state_class": "measurement",
            "unit_of_measurement": "VA",
        },
        "topic": "homeassistant/sensor/mocked_unipi/mocked_id_apparent_power/config",
    },
    {
        "message": {
            "name": "Reactive Power",
            "unique_id": "mocked_unipi_reactive_power_1",
            "state_topic": "mocked_unipi/meter/reactive_power_1/get",
            "qos": 2,
            "force_update": True,
            "device": {
                "name": "MOCKED Eastron SDM120M - Workspace",
                "identifiers": "mocked_eastron_sdm120m_workspace",
                "model": "SDM120M",
                "sw_version": "202.04",
                "manufacturer": "Eastron",
                "via_device": "MOCKED UNIPI",
                "suggested_area": "Workspace",
            },
            "object_id": "reactive_power_1",
            "device_class": "power",
            "state_class": "total",
            "unit_of_measurement": "W",
        },
        "topic": "homeassistant/sensor/mocked_unipi/reactive_power_1/config",
    },
    {
        "message": {
            "name": "Power Factor",
            "unique_id": "mocked_unipi_power_factor_1",
            "state_topic": "mocked_unipi/meter/power_factor_1/get",
            "qos": 2,
            "force_update": True,
            "device": {
                "name": "MOCKED Eastron SDM120M - Workspace",
                "identifiers": "mocked_eastron_sdm120m_workspace",
                "model": "SDM120M",
                "sw_version": "202.04",
                "manufacturer": "Eastron",
                "via_device": "MOCKED UNIPI",
                "suggested_area": "Workspace",
            },
            "object_id": "power_factor_1",
            "device_class": "power_factor",
            "state_class": "measurement",
        },
        "topic": "homeassistant/sensor/mocked_unipi/power_factor_1/config",
    },
    {
        "message": {
            "name": "Phase Angle",
            "unique_id": "mocked_unipi_phase_angle_1",
            "state_topic": "mocked_unipi/meter/phase_angle_1/get",
            "qos": 2,
            "force_update": True,
            "device": {
                "name": "MOCKED Eastron SDM120M - Workspace",
                "identifiers": "mocked_eastron_sdm120m_workspace",
                "model": "SDM120M",
                "sw_version": "202.04",
                "manufacturer": "Eastron",
                "via_device": "MOCKED UNIPI",
                "suggested_area": "Workspace",
            },
            "object_id": "phase_angle_1",
            "state_class": "measurement",
        },
        "topic": "homeassistant/sensor/mocked_unipi/phase_angle_1/config",
    },
    {
        "message": {
            "name": "Frequency",
            "unique_id": "mocked_unipi_frequency_1",
            "state_topic": "mocked_unipi/meter/frequency_1/get",
            "qos": 2,
            "force_update": True,
            "device": {
                "name": "MOCKED Eastron SDM120M - Workspace",
                "identifiers": "mocked_eastron_sdm120m_workspace",
                "model": "SDM120M",
                "sw_version": "202.04",
                "manufacturer": "Eastron",
                "via_device": "MOCKED UNIPI",
                "suggested_area": "Workspace",
            },
            "object_id": "frequency_1",
            "device_class": "frequency",
            "state_class": "measurement",
            "unit_of_measurement": "Hz",
        },
        "topic": "homeassistant/sensor/mocked_unipi/frequency_1/config",
    },
    {
        "message": {
            "name": "Import Active Energy",
            "unique_id": "mocked_unipi_import_active_energy_1",
            "state_topic": "mocked_unipi/meter/import_active_energy_1/get",
            "qos": 2,
            "force_update": True,
            "device": {
                "name": "MOCKED Eastron SDM120M - Workspace",
                "identifiers": "mocked_eastron_sdm120m_workspace",
                "model": "SDM120M",
                "sw_version": "202.04",
                "manufacturer": "Eastron",
                "via_device": "MOCKED UNIPI",
                "suggested_area": "Workspace",
            },
            "object_id": "import_active_energy_1",
            "device_class": "energy",
            "state_class": "total",
            "unit_of_measurement": "kWh",
        },
        "topic": "homeassistant/sensor/mocked_unipi/import_active_energy_1/config",
    },
    {
        "message": {
            "name": "Export Active Energy",
            "unique_id": "mocked_unipi_export_active_energy_1",
            "state_topic": "mocked_unipi/meter/export_active_energy_1/get",
            "qos": 2,
            "force_update": True,
            "device": {
                "name": "MOCKED Eastron SDM120M - Workspace",
                "identifiers": "mocked_eastron_sdm120m_workspace",
                "model": "SDM120M",
                "sw_version": "202.04",
                "manufacturer": "Eastron",
                "via_device": "MOCKED UNIPI",
                "suggested_area": "Workspace",
            },
            "object_id": "export_active_energy_1",
            "device_class": "energy",
            "state_class": "measurement",
            "unit_of_measurement": "kWh",
        },
        "topic": "homeassistant/sensor/mocked_unipi/export_active_energy_1/config",
    },
    {
        "message": {
            "name": "Import Reactive Energy",
            "unique_id": "mocked_unipi_import_reactive_energy_1",
            "state_topic": "mocked_unipi/meter/import_reactive_energy_1/get",
            "qos": 2,
            "force_update": True,
            "device": {
                "name": "MOCKED Eastron SDM120M - Workspace",
                "identifiers": "mocked_eastron_sdm120m_workspace",
                "model": "SDM120M",
                "sw_version": "202.04",
                "manufacturer": "Eastron",
                "via_device": "MOCKED UNIPI",
                "suggested_area": "Workspace",
            },
            "object_id": "import_reactive_energy_1",
            "state_class": "total",
            "unit_of_measurement": "kvarh",
        },
        "topic": "homeassistant/sensor/mocked_unipi/import_reactive_energy_1/config",
    },
    {
        "message": {
            "name": "Export Reactive Energy",
            "unique_id": "mocked_unipi_export_reactive_energy_1",
            "state_topic": "mocked_unipi/meter/export_reactive_energy_1/get",
            "qos": 2,
            "force_update": True,
            "device": {
                "name": "MOCKED Eastron SDM120M - Workspace",
                "identifiers": "mocked_eastron_sdm120m_workspace",
                "model": "SDM120M",
                "sw_version": "202.04",
                "manufacturer": "Eastron",
                "via_device": "MOCKED UNIPI",
                "suggested_area": "Workspace",
            },
            "object_id": "export_reactive_energy_1",
            "state_class": "total",
            "unit_of_measurement": "kvarh",
        },
        "topic": "homeassistant/sensor/mocked_unipi/export_reactive_energy_1/config",
    },
    {
        "message": {
            "name": "Total System Power Demand",
            "unique_id": "mocked_unipi_total_system_power_demand_1",
            "state_topic": "mocked_unipi/meter/total_system_power_demand_1/get",
            "qos": 2,
            "force_update": True,
            "device": {
                "name": "MOCKED Eastron SDM120M - Workspace",
                "identifiers": "mocked_eastron_sdm120m_workspace",
                "model": "SDM120M",
                "sw_version": "202.04",
                "manufacturer": "Eastron",
                "via_device": "MOCKED UNIPI",
                "suggested_area": "Workspace",
            },
            "object_id": "total_system_power_demand_1",
            "device_class": "power",
            "state_class": "measurement",
            "unit_of_measurement": "W",
        },
        "topic": "homeassistant/sensor/mocked_unipi/total_system_power_demand_1/config",
    },
    {
        "message": {
            "name": "Maximum Total System Power Demand",
            "unique_id": "mocked_unipi_maximum_total_system_power_demand_1",
            "state_topic": "mocked_unipi/meter/maximum_total_system_power_demand_1/get",
            "qos": 2,
            "force_update": True,
            "device": {
                "name": "MOCKED Eastron SDM120M - Workspace",
                "identifiers": "mocked_eastron_sdm120m_workspace",
                "model": "SDM120M",
                "sw_version": "202.04",
                "manufacturer": "Eastron",
                "via_device": "MOCKED UNIPI",
                "suggested_area": "Workspace",
            },
            "object_id": "maximum_total_system_power_demand_1",
            "device_class": "power",
            "state_class": "total",
            "unit_of_measurement": "W",
        },
        "topic": "homeassistant/sensor/mocked_unipi/maximum_total_system_power_demand_1/config",
    },
    {
        "message": {
            "name": "Import System Power Demand",
            "unique_id": "mocked_unipi_import_system_power_demand_1",
            "state_topic": "mocked_unipi/meter/import_system_power_demand_1/get",
            "qos": 2,
            "force_update": True,
            "device": {
                "name": "MOCKED Eastron SDM120M - Workspace",
                "identifiers": "mocked_eastron_sdm120m_workspace",
                "model": "SDM120M",
                "sw_version": "202.04",
                "manufacturer": "Eastron",
                "via_device": "MOCKED UNIPI",
                "suggested_area": "Workspace",
            },
            "object_id": "import_system_power_demand_1",
            "device_class": "power",
            "state_class": "measurement",
            "unit_of_measurement": "W",
        },
        "topic": "homeassistant/sensor/mocked_unipi/import_system_power_demand_1/config",
    },
    {
        "message": {
            "name": "Maximum Import System Power Demand",
            "unique_id": "mocked_unipi_maximum_import_system_power_demand_1",
            "state_topic": "mocked_unipi/meter/maximum_import_system_power_demand_1/get",
            "qos": 2,
            "force_update": True,
            "device": {
                "name": "MOCKED Eastron SDM120M - Workspace",
                "identifiers": "mocked_eastron_sdm120m_workspace",
                "model": "SDM120M",
                "sw_version": "202.04",
                "manufacturer": "Eastron",
                "via_device": "MOCKED UNIPI",
                "suggested_area": "Workspace",
            },
            "object_id": "maximum_import_system_power_demand_1",
            "device_class": "power",
            "state_class": "measurement",
            "unit_of_measurement": "W",
        },
        "topic": "homeassistant/sensor/mocked_unipi/maximum_import_system_power_demand_1/config",
    },
    {
        "message": {
            "name": "Export System Power Demand",
            "unique_id": "mocked_unipi_export_system_power_demand_1",
            "state_topic": "mocked_unipi/meter/export_system_power_demand_1/get",
            "qos": 2,
            "force_update": True,
            "device": {
                "name": "MOCKED Eastron SDM120M - Workspace",
                "identifiers": "mocked_eastron_sdm120m_workspace",
                "model": "SDM120M",
                "sw_version": "202.04",
                "manufacturer": "Eastron",
                "via_device": "MOCKED UNIPI",
                "suggested_area": "Workspace",
            },
            "object_id": "export_system_power_demand_1",
            "device_class": "power",
            "state_class": "measurement",
            "unit_of_measurement": "W",
        },
        "topic": "homeassistant/sensor/mocked_unipi/export_system_power_demand_1/config",
    },
    {
        "message": {
            "name": "Maximum Export System Power Demand",
            "unique_id": "mocked_unipi_maximum_export_system_power_demand_1",
            "state_topic": "mocked_unipi/meter/maximum_export_system_power_demand_1/get",
            "qos": 2,
            "force_update": True,
            "device": {
                "name": "MOCKED Eastron SDM120M - Workspace",
                "identifiers": "mocked_eastron_sdm120m_workspace",
                "model": "SDM120M",
                "sw_version": "202.04",
                "manufacturer": "Eastron",
                "via_device": "MOCKED UNIPI",
                "suggested_area": "Workspace",
            },
            "object_id": "maximum_export_system_power_demand_1",
            "device_class": "power",
            "state_class": "measurement",
            "unit_of_measurement": "W",
        },
        "topic": "homeassistant/sensor/mocked_unipi/maximum_export_system_power_demand_1/config",
    },
    {
        "message": {
            "name": "Current Demand",
            "unique_id": "mocked_unipi_current_demand_1",
            "state_topic": "mocked_unipi/meter/current_demand_1/get",
            "qos": 2,
            "force_update": True,
            "device": {
                "name": "MOCKED Eastron SDM120M - Workspace",
                "identifiers": "mocked_eastron_sdm120m_workspace",
                "model": "SDM120M",
                "sw_version": "202.04",
                "manufacturer": "Eastron",
                "via_device": "MOCKED UNIPI",
                "suggested_area": "Workspace",
            },
            "object_id": "current_demand_1",
            "device_class": "current",
            "state_class": "measurement",
            "unit_of_measurement": "A",
        },
        "topic": "homeassistant/sensor/mocked_unipi/current_demand_1/config",
    },
    {
        "message": {
            "name": "Maximum Current Demand",
            "unique_id": "mocked_unipi_maximum_current_demand_1",
            "state_topic": "mocked_unipi/meter/maximum_current_demand_1/get",
            "qos": 2,
            "force_update": True,
            "device": {
                "name": "MOCKED Eastron SDM120M - Workspace",
                "identifiers": "mocked_eastron_sdm120m_workspace",
                "model": "SDM120M",
                "sw_version": "202.04",
                "manufacturer": "Eastron",
                "via_device": "MOCKED UNIPI",
                "suggested_area": "Workspace",
            },
            "object_id": "maximum_current_demand_1",
            "device_class": "current",
            "state_class": "measurement",
            "unit_of_measurement": "A",
        },
        "topic": "homeassistant/sensor/mocked_unipi/maximum_current_demand_1/config",
    },
    {
        "message": {
            "name": "Total Active Energy",
            "unique_id": "mocked_unipi_total_active_energy_1",
            "state_topic": "mocked_unipi/meter/total_active_energy_1/get",
            "qos": 2,
            "force_update": True,
            "device": {
                "name": "MOCKED Eastron SDM120M - Workspace",
                "identifiers": "mocked_eastron_sdm120m_workspace",
                "model": "SDM120M",
                "sw_version": "202.04",
                "manufacturer": "Eastron",
                "via_device": "MOCKED UNIPI",
                "suggested_area": "Workspace",
            },
            "object_id": "total_active_energy_1",
            "device_class": "energy",
            "state_class": "total",
            "unit_of_measurement": "kWh",
        },
        "topic": "homeassistant/sensor/mocked_unipi/total_active_energy_1/config",
    },
    {
        "message": {
            "name": "Total Reactive Energy",
            "unique_id": "mocked_unipi_total_reactive_energy_1",
            "state_topic": "mocked_unipi/meter/total_reactive_energy_1/get",
            "qos": 2,
            "force_update": True,
            "device": {
                "name": "MOCKED Eastron SDM120M - Workspace",
                "identifiers": "mocked_eastron_sdm120m_workspace",
                "model": "SDM120M",
                "sw_version": "202.04",
                "manufacturer": "Eastron",
                "via_device": "MOCKED UNIPI",
                "suggested_area": "Workspace",
            },
            "object_id": "total_reactive_energy_1",
            "state_class": "total",
            "unit_of_measurement": "kvarh",
        },
        "topic": "homeassistant/sensor/mocked_unipi/total_reactive_energy_1/config",
    },
]
